{% load django_tables2 %}
{% load i18n %}
{% block table-wrapper %}
<div class="table-container">
    {% block table %}
        <table {% render_attrs table.attrs class="table" %}>
            {% block table.thead %}
            {% if table.show_header %}
                <thead {{ table.attrs.thead.as_html }}>
                    <tr>
                    {% for column in table.columns %}
                        <th {{ column.attrs.th.as_html }}>
                            {% if column.orderable %}
                                <a href="{% querystring table.prefixed_order_by_field=column.order_by_alias.next %}">{{ column.header }}</a>
                            {% else %}
                                {{ column.header }}
                            {% endif %}
                        </th>
                    {% endfor %}
                    </tr>
                </thead>
            {% endif %}
            {% endblock table.thead %}
            {% block table.tbody %}
                <tbody {{ table.attrs.tbody.as_html }}>
                {% for row in table.paginated_rows %}
                    {% block table.tbody.row %}
                    <tr {{ row.attrs.as_html }}>
                        {% for column, cell in row.items %}
                            <td {{ column.attrs.td.as_html }}>{% if column.localize == None %}{{ cell }}{% else %}{% if column.localize %}{{ cell|localize }}{% else %}{{ cell|unlocalize }}{% endif %}{% endif %}</td>
                        {% endfor %}
                    </tr>
                    {% endblock table.tbody.row %}
                {% empty %}
                    {% if table.empty_text %}
                    {% block table.tbody.empty_text %}
                        <tr><td colspan="{{ table.columns|length }}">{{ table.empty_text }}</td></tr>
                    {% endblock table.tbody.empty_text %}
                    {% endif %}
                {% endfor %}
                </tbody>
            {% endblock table.tbody %}
            {% block table.tfoot %}
            {% if table.has_footer %}
                <tfoot {{ table.attrs.tfoot.as_html }}>
                    <tr>
                    {% for column in table.columns %}
                        <td {{ column.attrs.tf.as_html }}>{{ column.footer }}</td>
                    {% endfor %}
                    </tr>
                </tfoot>
            {% endif %}
            {% endblock table.tfoot %}
        </table>
    {% endblock table %}

    {% block pagination %}
        {% if table.page and table.paginator.num_pages > 1 %}
        <nav aria-label="Table navigation">
            <ul class="pagination">
            {% if table.page.has_previous %}
                {% block pagination.previous %}
                    <li class="previous">
                        <a href="{% querystring table.prefixed_page_field=table.page.previous_page_number %}">
                            <span aria-hidden="true">&laquo;</span>
                            {% trans 'previous' %}
                        </a>
                    </li>
                {% endblock pagination.previous %}
            {% endif %}
            {% if table.page.has_previous or table.page.has_next %}
                {% block pagination.range %}
                    {% for p in table.page|table_page_range:table.paginator %}
                        <li {% if p == table.page.number %}class="active"{% endif %}>
                            {% if p == '...' %}
                                <a href="#">{{ p }}</a>
                            {% else %}
                                <a href="{% querystring table.prefixed_page_field=p %}">
                                    {{ p }}
                                </a>
                            {% endif %}
                        </li>
                    {% endfor %}
                {% endblock pagination.range %}
            {% endif %}

            {% if table.page.has_next %}
                {% block pagination.next %}
                <li class="next">
                    <a href="{% querystring table.prefixed_page_field=table.page.next_page_number %}">
                        {% trans 'next' %}
                        <span aria-hidden="true">&raquo;</span>
                    </a>
                </li>
                {% endblock pagination.next %}
            {% endif %}
            </ul>
        </nav>
        {% endif %}
    {% endblock pagination %}
</div>
{% endblock table-wrapper %}
