{% load django_tables2 %}
{% load static %}
<!doctype html>
<html>
    <head>
        <link rel="stylesheet" href="{% static 'django_tables2/themes/paleblue/css/screen.css' %}" />
    </head>
    <body>
        <h3>django_tables2 with the default template example</h3>

        {% render_table table %}
    </body>
</html>
